pub unsafe extern "C" fn LLVMContextSetOpaquePointers(
C: LLVMContextRef,
OpaquePointers: LLVMBool,
)Expand description
Set whether the given context is in opaque pointer mode.
pub unsafe extern "C" fn LLVMContextSetOpaquePointers(
C: LLVMContextRef,
OpaquePointers: LLVMBool,
)Set whether the given context is in opaque pointer mode.